coastpy package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   coastpy.geo
   coastpy.io
   coastpy.libs
   coastpy.stac
   coastpy.stats
   coastpy.utils

Module contents
---------------

.. automodule:: coastpy
   :members:
   :undoc-members:
   :show-inheritance:
